proton-cli 0.0.0

A template command line application written in Rust leveraging the clap framework
proton-cli-0.0.0 is not a library.

proton-cli

[license]


The application is currently in the early stages of development and is not yet ready for production use.

A template for creating a CLI application in Rust using clap.

Features

  • Feature 1

Getting Started

Building from the source

Start by cloning the repository

git clone https://github.com/FL03/template-rs-cli.git

Change directory

cd template-rs-cli

Building the project

cargo build --all-features -r -v --workspace

Running tests

cargo test --all-features -r -v --workspace

Usage

Add this to your Cargo.toml:

cargo install template-rs-cli